@@ -1,6 +1,6 @@
 /*******************************************************************************
  * #-------------------------------------------------------------------------------
- * # Copyright (c) 2003-2016 IPI PAN.
+ * # dmLab 2003-2019
  * # All rights reserved. This program and the accompanying materials
  * # are made available under the terms of the GNU Public License v3.0
  * # which accompanies this distribution, and is available at
@@ -15,11 +15,6 @@
  * # Algorithm 'SLIQ' developed by Mariusz Gromada
  * # R Package developed by Michal Draminski & Julian Zubek
  * #-------------------------------------------------------------------------------
- * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
- * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
- * # "Monte Carlo feature selection for supervised classification", 
- * # BIOINFORMATICS 24(1): 110-117 (2008)
- * #-------------------------------------------------------------------------------
  *******************************************************************************/
 package dmLab.array.meta;
 
@@ -34,13 +29,29 @@ public class Attribute implements Cloneable
   public static final short INTEGER = 3;
   
   public String name;
+  public short weight;
   public short type;
   
 //****************************************
   public Attribute()
   {
     name = null;
-    type = UNKNOWN;    
+    type = UNKNOWN;
+    weight = 1;
+  }
+//****************************************
+  public Attribute(String name, short type)
+  {
+    this.name = name;
+    this.type = type;
+    this.weight = 1;
+  }
+//****************************************
+  public Attribute(String name, short type, short weight)
+  {
+    this.name = name;
+    this.type = type;
+    this.weight = weight;
   }
 //****************************************
    public static String type2String(short type)
@@ -89,13 +100,20 @@ public class Attribute implements Cloneable
 	   Attribute a = new Attribute();
 	   a.name = name;
 	   a.type = type;
+	   a.weight = weight;
 	   return a; 
    }
 // ********************************************
    @Override
    public String toString()
    {
-       return name+" "+type;
+       return name + " " + type;
    }
 // ********************************************
+   public String toString2()
+   {
+       return name + " " + type + " [" + weight + "]";
+   }
+// ********************************************
+
 }
