@@ -1,6 +1,6 @@
 /*******************************************************************************
  * #-------------------------------------------------------------------------------
- * # Copyright (c) 2003-2016 IPI PAN.
+ * # dmLab 2003-2019
  * # All rights reserved. This program and the accompanying materials
  * # are made available under the terms of the GNU Public License v3.0
  * # which accompanies this distribution, and is available at
@@ -15,11 +15,6 @@
  * # Algorithm 'SLIQ' developed by Mariusz Gromada
  * # R Package developed by Michal Draminski & Julian Zubek
  * #-------------------------------------------------------------------------------
- * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
- * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
- * # "Monte Carlo feature selection for supervised classification", 
- * # BIOINFORMATICS 24(1): 110-117 (2008)
- * #-------------------------------------------------------------------------------
  *******************************************************************************/
 package dmLab.mcfs.mcfsEngine.framework;
 
@@ -46,7 +41,7 @@ public class MCFSJob implements Runnable
 	protected ConfusionMatrix localMatrix;
 	protected BufferedWriter accFile;
 
-	protected MCFSParams mcfsParams;    
+	protected MCFSParams mcfsParams;
 	protected FArray inputArray;
 	protected AttributesRI localImportance[];
 	protected AttributesID localAttrID;
@@ -119,16 +114,17 @@ public class MCFSJob implements Runnable
 	//************************************    
 	public void run() 
 	{
-		boolean keepLoop=true;
-		int loopIndex=0;
+		boolean keepLoop = true;
+		int localloopIndex = 0;
 		while(keepLoop){
+			//System.out.println("@@@ Thread: " + jobId + " starts projection *** ");
 			ConfusionMatrix matrix = projection.projectionLoop(classifier, inputArray, localImportance, localAttrID);
 			if(localMatrix != null){
 				localMatrix.add(matrix);
 			}
 			localSplitsStats.add(projection.getSplitsStats());
 			//every saveResultInterval update global stats
-			if(loopIndex%mcfsParams.progressInterval==0 && loopIndex!=0){
+			if(localloopIndex%mcfsParams.progressInterval==0 && localloopIndex!=0){
 				//System.out.println("@@@ Thread: " + jobId + " updating global stats *** ");
 				//save from local to global                
 				keepLoop = globalStats.update(jobId, localMatrix, localImportance, localAttrID);
@@ -141,10 +137,10 @@ public class MCFSJob implements Runnable
 					localMatrix.cleanMatrix();
 				}
 				
-				if(localAttrID!=null)
+				if(localAttrID != null)
 					localAttrID.init();
 			}
-			loopIndex++;
+			localloopIndex++;
 		}
 		//update acc_wAcc stats after job is finished
 		globalStats.updateSplitsStats(localSplitsStats);
